@@ -4,7 +4,7 @@ use 5.008003;
 use warnings;
 use strict;
 
-our $VERSION = '0.992';
+our $VERSION = '0.994';
 
 # Documentation module only.
 
@@ -15,7 +15,7 @@ __END__
 
 =begin readme text
 
-Dist::Zilla::BeLike::CSJEWELL version 0.990
+Dist::Zilla::BeLike::CSJEWELL version 0.994
 
 =end readme
 
@@ -27,9 +27,9 @@ Dist::Zilla::BeLike::CSJEWELL - Build a modern dist like CSJEWELL does it.
 
 =head1 VERSION
 
-This document describes Dist::Zilla::BeLike::CSJEWELL version 0.901.
+This document describes Dist::Zilla::BeLike::CSJEWELL version 0.994.
 
-=begin readme
+=for readme continue
 
 =head1 INSTALLATION
 
@@ -50,14 +50,12 @@ Alternatively, to install with Module::Build, you can use the following commands
     ./Build test
     ./Build install
 
-=end readme
-
 =for readme stop
 
 =head1 SYNOPSIS
 
     # After 'dzil setup'
-    dzil configure_CSJEWELL
+    dzil configure_csjewell
     
     # To create a module
     dzil new -P CSJEWELL Your::Module
@@ -75,8 +73,8 @@ The configuration questions are asked for in the C<dzil configure_CSJEWELL> comm
 
 =head1 DEPENDENCIES
 
-This module depends on L<Dist::Zilla|Dist::Zilla> version 4.102221 or greater,
-L<Dist::Zilla::Plugin::Mercurial|Dist::Zilla::Plugin::Mercurial>, 
+This module depends on L<Dist::Zilla|Dist::Zilla> version 6.012 or greater,
+L<Dist::Zilla::Plugin::Git|Dist::Zilla::Plugin::Git>, 
 L<Dist::Zilla::Plugin::Twitter|Dist::Zilla::Plugin::Twitter>, ...
 
 =for readme stop
@@ -87,9 +85,6 @@ None reported.
 
 =head1 BUGS AND LIMITATIONS
 
-This module does not know how to automatically handle any Mercurial servers 
-other than bitbucket.org, or any other VCS or DVCS server at the moment.
-
 No bugs have been reported.
 
 Bugs should be reported via: 
@@ -107,7 +102,7 @@ Curtis Jewell <CSJewell@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2010, Curtis Jewell C<< CSJewell@cpan.org >>.
+Copyright (c) 2010, 2014, 2021 Curtis Jewell C<< CSJewell@cpan.org >>.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself, either version
